@@ -8,7 +8,6 @@ from pythran.typing import List, NDArray, Tuple
 from pythran.tests import TestEnv
 
 
-@TestEnv.module
 class TestNumpyFunc3(TestEnv):
 
     """
@@ -304,6 +303,84 @@ class TestNumpyFunc3(TestEnv):
                       np_dot24=[NDArray[numpy.float32,:,:,:],
                                 NDArray[numpy.float64,:,:,:,:]])
 
+    def test_dot25(self):
+        ''' 1d x 1d, slice'''
+        self.run_test("""
+        def np_dot25(x, y):
+            from numpy import dot
+            return dot(x[1:], y[:-1])""",
+                      numpy.arange(24., dtype=numpy.float32),
+                      numpy.arange(24., dtype=numpy.float32),
+                      np_dot25=[NDArray[numpy.float32,:],
+                                NDArray[numpy.float32,:]])
+
+    def test_dot26(self):
+        ''' 1d x 1d, slice'''
+        self.run_test("""
+        def np_dot26(x, y):
+            from numpy import dot
+            return dot(x[1:], y[:-1])""",
+                      numpy.arange(24., dtype=numpy.float64),
+                      numpy.arange(24., dtype=numpy.float64),
+                      np_dot26=[NDArray[numpy.float64,:],
+                                NDArray[numpy.float64,:]])
+
+    def test_dot27(self):
+        ''' 1d x 1d, slice'''
+        self.run_test("""
+        def np_dot27(x, y):
+            from numpy import dot
+            return dot(x[1:], y[:-1])""",
+                      numpy.arange(24., dtype=numpy.complex64),
+                      numpy.arange(24., dtype=numpy.complex64),
+                      np_dot27=[NDArray[numpy.complex64,:],
+                                NDArray[numpy.complex64,:]])
+
+    def test_dot28(self):
+        ''' 1d x 1d, slice'''
+        self.run_test("""
+        def np_dot28(x, y):
+            from numpy import dot
+            return dot(x[1:], y[:-1])""",
+                      numpy.arange(24., dtype=numpy.complex128),
+                      numpy.arange(24., dtype=numpy.complex128),
+                      np_dot28=[NDArray[numpy.complex128,:],
+                                NDArray[numpy.complex128,:]])
+
+    def test_dot29(self):
+        ''' 1d x 1d, slice'''
+        self.run_test("""
+        def np_dot29(x, y):
+            from numpy import dot
+            return dot(x[-1:0:-1], y[:-1])""",
+                      numpy.arange(24., dtype=numpy.float32),
+                      numpy.arange(24., dtype=numpy.float32),
+                      np_dot29=[NDArray[numpy.float32,:],
+                                NDArray[numpy.float32,:]])
+
+    def test_dot30(self):
+        ''' 1d x 1d, slice'''
+        self.run_test("""
+        def np_dot30(x, y):
+            from numpy import dot
+            return dot(x[-1:0:-1], y[-1:0:-1])""",
+                      numpy.arange(24., dtype=numpy.float32),
+                      numpy.arange(24., dtype=numpy.float32),
+                      np_dot30=[NDArray[numpy.float32,:],
+                                NDArray[numpy.float32,:]])
+
+    def test_dot31(self):
+        ''' 1d x 1d, expr'''
+        self.run_test("""
+        def np_dot31(x):
+            import numpy  as np
+            func = np.exp(-2j * np.pi * np.arange(len(x)))
+            normFunc = np.sqrt(np.real(np.dot(np.conjugate(func), func)))
+            return normFunc
+        """,
+                      numpy.arange(24., dtype=numpy.float32),
+                      np_dot31=[NDArray[numpy.float32,:]])
+
     def test_vdot0(self):
         self.run_test("""
         def np_vdot0(x, y):
@@ -527,6 +604,11 @@ def np_trim_zeros2(x):
                       numpy.array([[1,2], [7, 8]]), numpy.array([3,4]),
                       np_copyto1=[NDArray[int, :, :], NDArray[int, :]])
 
+    def test_copyto_2(self):
+        self.run_test("def np_copyto2(x, y): from numpy import copyto; return copyto(x.T, y), x",
+                      numpy.array([[1,2], [7, 8]]), numpy.array([3,4]),
+                      np_copyto2=[NDArray[int, :, :], NDArray[int, :]])
+
     def test_numpy_pow0(self):
         self.run_test('def numpy_pow0(a): return a ** 2',
                       numpy.arange(100).reshape((10, 10)),
